* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Application Modeling Guidelines](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines)
  * AI Agent Modeling Guidelines
